<!DOCTYPE TS><TS>
<context>
    <name>AdvSearch</name>
    <message>
        <source>All clauses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Any clause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>texts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>spreadsheets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>presentations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>other</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot execute pure negative query. Please enter common terms in the &apos;any words&apos; field</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdvSearchBase</name>
    <message>
        <source>Advanced search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search for &lt;br&gt;documents&lt;br&gt;satisfying:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All non blank fields will be combined with OR or AND conjunctions. &lt;br&gt;&quot;Any&quot; &quot;All&quot; and &quot;None&quot; field types can accept a mix of simple words, and phrases enclosed in double quotes.&lt;br&gt;Fields with no data are ignored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete clause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add clause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restrict file types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this to enable filtering on file types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this to use file categories instead of raw mime types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save as default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Searched file types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All ----&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sel -----&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;----- Sel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;----- All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignored file types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter top directory for search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restrict results to files in subtree:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Configuration problem: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configuration problem (dynconf</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No db directory in configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not open database in </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>.
Click Cancel if you want to edit the configuration file before indexation starts, or Ok to let it proceed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Preview</name>
    <message>
        <source>Close Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot create temporary directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing helper program: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t turn doc into internal representation for </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creating preview text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading preview text into editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Search for:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Match &amp;Case</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Global parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Local parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Customised subtrees</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The list of subdirectories in the indexed hierarchy &lt;br&gt;where some parameters need to be redefined. Default: empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;i&gt;The parameters that follow are set either at the top level, if nothing&lt;br&gt;or an empty line is selected in the listbox above, or for the selected subdirectory.&lt;br&gt;You can add or remove directories by clicking the +/- buttons.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipped names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>These are patterns for file or directory  names which should not be indexed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default character set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the character set used for reading files which do not identify the character set internally, for example pure text files.&lt;br&gt;The default value is empty, and the value from the NLS environnement is used.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Follow symbolic links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Follow symbolic links while indexing. The default is no, to avoid duplicate indexing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Index all file names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Index the names of files for which the contents cannot be identified or processed (no or unsupported mime type). Default true</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RclMain</name>
    <message>
        <source>(no stemming)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(all languages)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indexing in progress: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Purge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stemdb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Closing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t start query: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Query results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot retrieve document info from database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot access document file: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t create preview window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This search is not active any more</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No external viewer configured for mime type </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bad viewer command line for %1: [%2]
Please check the mimeconf file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The viewer specified in mimeconf for %1: %2 is not found.
Do you want to start the  preferences dialog ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot extract document or create temporary file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Executing: [</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Recoll</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Starting help browser </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>History data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update &amp;Index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indexing interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop &amp;Indexing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>other</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>presentation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sorted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>filtered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>External applications/commands needed and not found for indexing your file types:

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No helpers found missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing helper programs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RclMainBase</name>
    <message>
        <source>Recoll</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Result list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update &amp;index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Erase document history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;About Recoll</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;User manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document &amp;History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document  History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Advanced Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced/complex  Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Sort parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Term &amp;explorer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Term explorer tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next page of results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>First page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go to first page of results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous page of results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Query configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>External index dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Indexing configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Show missing helpers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ResList</name>
    <message>
        <source>Result list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show query details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%1-%2&lt;/b&gt; out of at least &lt;b&gt;%3&lt;/b&gt; for </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents &lt;b&gt;%1-%2&lt;/b&gt; for </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(show query)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unavailable document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy &amp;File Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy &amp;URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find &amp;similar documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>P&amp;arent document/folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Query details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>filtered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sorted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SSearch</name>
    <message>
        <source>Any term</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All terms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Query language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bad query string</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Out of memory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Too many completions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Completions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an item:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SSearchBase</name>
    <message>
        <source>SSearchBase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Erase search entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start query</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose type of search: any term, all terms, filename with possible wildcards.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter search terms here. Type ESC SPC for completions of current term.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchClauseW</name>
    <message>
        <source>SearchClauseW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Any of these</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All of these</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None of these</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This phrase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Terms in proximity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File name matching</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select the type of query that will be performed with the words</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of additional words that may be interspersed with the chosen ones</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SortForm</name>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mime type</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SortFormBase</name>
    <message>
        <source>Sort Criteria</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort the</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>most relevant results by:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SpellBase</name>
    <message>
        <source>Term Explorer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Expand </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Term</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Count</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SpellW</name>
    <message>
        <source>Wildcards</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Regexp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stem expansion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spelling/Phonetic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aspell init failed. Aspell not installed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aspell expansion error. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No expansion found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UIPrefsDialog</name>
    <message>
        <source>error retrieving stemming languages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selected directory does not appear to be a Xapian index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the main/local index!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selected directory is already in the index list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select xapian index directory (ie: /home/buddy/.recoll/xapiandb)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UIPrefsDialogBase</name>
    <message>
        <source>User preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of entries in a result page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Result list font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Helvetica-10</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opens a dialog to select the result list font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resets the result list font to the system default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Result paragraph&lt;br&gt;format string</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Defines the format for each result list paragraph. Use qt html format and printf-like replacements:&lt;br&gt;%A Abstract&lt;br&gt; %D Date&lt;br&gt; %I Icon image name&lt;br&gt; %K Keywords (if any)&lt;br&gt; %L Preview and Edit links&lt;br&gt; %M Mime type&lt;br&gt; %N Result number&lt;br&gt; %R Relevance percentage&lt;br&gt; %S Size information&lt;br&gt; %T Title&lt;br&gt; %U Url&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Texts over this size will not be highlighted in preview (too slow).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum text size highlighted for preview (megabytes)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HTML help browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose external viewer applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-start simple search on whitespace entry.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start with advanced search dialog open.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start with sort dialog open.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use desktop preferences to choose document editor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember sort activation state.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stemming language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically add phrase to simple searches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A search for [rolling stones] (2 terms) will be changed to [rolling or stones or (rolling phrase 2 stones)]. 
This should give higher precedence to the results where the search terms appear exactly as entered.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dynamically build abstracts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do we try to build abstracts for result list entries by using the context of query terms ? 
May be slow for big documents.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace abstracts from documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do we synthetize an abstract even if the document seemed to have one?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Synthetic abstract size (characters)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Synthetic abstract context words</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>External Indexes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>External indexes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Activate All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deactivate All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from list. This has no effect on the disk index.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select the xapiandb directory for the index you want to add, then click Add Index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Discard changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Highlight color for query terms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prefer Html to plain text for preview.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewAction</name>
    <message>
        <source>Changing actions with different current values</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewActionBase</name>
    <message>
        <source>Native Viewers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select one or several file types, then click Change Action to modify the program used to open them</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>confgui::ConfIndexW</name>
    <message>
        <source>Can&apos;t write configuration file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>confgui::ConfParamFNW</name>
    <message>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>confgui::ConfParamSLW</name>
    <message>
        <source>+</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>-</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>confgui::ConfSubPanelW</name>
    <message>
        <source>Global</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>confgui::ConfTopPanelW</name>
    <message>
        <source>Top directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The list of directories where recursive indexing starts. Default: your home.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipped paths</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>These are names of directories which indexing will not enter.&lt;br&gt; May contain wildcards. Must match the paths seen by the indexer (ie: if topdirs includes &apos;/home/me&apos; and &apos;/home&apos; is actually a link to &apos;/usr/home&apos;, a correct skippedPath entry would be &apos;/home/me/tmp*&apos;, not &apos;/usr/home/me/tmp*&apos;)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stemming languages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The languages for which stemming expansion&lt;br&gt;dictionaries will be built.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log file name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The file where the messages will be written.&lt;br&gt;Use &apos;stderr&apos; for terminal output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log verbosity level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This value adjusts the amount of messages,&lt;br&gt;from only errors to a lot of debugging data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Index flush megabytes interval</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This value adjust the amount of data which is indexed between flushes to disk.&lt;br&gt;This helps control the indexer memory usage. Default 10MB </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max disk occupation (%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the percentage of disk occupation where indexing will fail and stop (to avoid filling up your disk).&lt;br&gt;0 means no limit (this is the default).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No aspell usage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aspell language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The language for the aspell dictionary. This should look like &apos;en&apos; or &apos;fr&apos; ...&lt;br&gt;If this value is not set, the NLS environment will be used to compute it, which usually works.To get an idea of what is installed on your system, type &apos;aspell config&apos; and look for .dat files inside the &apos;data-dir&apos; directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database directory name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name for a directory where to store the index&lt;br&gt;A non-absolute path is taken relative to the  configuration directory. The default is &apos;xapiandb&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use system&apos;s &apos;file&apos; command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the system&apos;s &apos;file&apos; command if internal&lt;br&gt;mime type identification fails.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disables use of aspell to generate spelling approximation in the term explorer tool.&lt;br&gt; Useful if aspell is absent or does not work. </source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
